"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
import pydantic
from supertone.types import BaseModel
from typing import Optional
from typing_extensions import Annotated, NotRequired, TypedDict


class GetUsageResponseV1DataTypedDict(TypedDict):
    date_: str
    r"""The date of the API usage in YYYY-MM-DD format."""
    voice_id: str
    r"""The unique identifier for the voice used in the API call."""
    total_minutes_used: float
    r"""The total duration (in minutes) of API usage for the specified voice and date."""
    name: NotRequired[str]
    r"""The name of the voice used in the API call."""
    style: NotRequired[str]
    r"""The style of the voice used in the API call."""
    language: NotRequired[str]
    r"""The language of the voice used in the API call."""
    model: NotRequired[str]
    r"""The model name used for text-to-speech."""
    thumbnail_url: NotRequired[str]
    r"""The URL to the thumbnail image for the voice."""


class GetUsageResponseV1Data(BaseModel):
    date_: Annotated[str, pydantic.Field(alias="date")]
    r"""The date of the API usage in YYYY-MM-DD format."""

    voice_id: str
    r"""The unique identifier for the voice used in the API call."""

    total_minutes_used: float
    r"""The total duration (in minutes) of API usage for the specified voice and date."""

    name: Optional[str] = None
    r"""The name of the voice used in the API call."""

    style: Optional[str] = None
    r"""The style of the voice used in the API call."""

    language: Optional[str] = None
    r"""The language of the voice used in the API call."""

    model: Optional[str] = None
    r"""The model name used for text-to-speech."""

    thumbnail_url: Optional[str] = None
    r"""The URL to the thumbnail image for the voice."""
