"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .usageresult import UsageResult, UsageResultTypedDict
from supertone.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class UsageBucketTypedDict(TypedDict):
    starting_at: str
    r"""RFC3339 timestamp for bucket start"""
    ending_at: str
    r"""RFC3339 timestamp for bucket end"""
    results: List[UsageResultTypedDict]
    r"""Array of usage results within this time bucket"""


class UsageBucket(BaseModel):
    starting_at: str
    r"""RFC3339 timestamp for bucket start"""

    ending_at: str
    r"""RFC3339 timestamp for bucket end"""

    results: List[UsageResult]
    r"""Array of usage results within this time bucket"""
