"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .updateclonedvoicerequest import (
    UpdateClonedVoiceRequest,
    UpdateClonedVoiceRequestTypedDict,
)
from supertone.types import BaseModel
from supertone.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class EditCustomVoiceRequestTypedDict(TypedDict):
    voice_id: str
    update_cloned_voice_request: UpdateClonedVoiceRequestTypedDict


class EditCustomVoiceRequest(BaseModel):
    voice_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    update_cloned_voice_request: Annotated[
        UpdateClonedVoiceRequest,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
