"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from typing import TYPE_CHECKING
from importlib import import_module
import builtins

if TYPE_CHECKING:
    from .apiconverttexttospeechusingcharacterrequest import (
        APIConvertTextToSpeechUsingCharacterRequest,
        APIConvertTextToSpeechUsingCharacterRequestLanguage,
        APIConvertTextToSpeechUsingCharacterRequestOutputFormat,
        APIConvertTextToSpeechUsingCharacterRequestTypedDict,
    )
    from .apisampledata import APISampleData, APISampleDataTypedDict
    from .converttexttospeechparameters import (
        ConvertTextToSpeechParameters,
        ConvertTextToSpeechParametersTypedDict,
    )
    from .create_cloned_voiceop import (
        CreateClonedVoiceRequest,
        CreateClonedVoiceRequestTypedDict,
        Files,
        FilesTypedDict,
    )
    from .create_speechop import (
        CreateSpeechRequest,
        CreateSpeechRequestTypedDict,
        CreateSpeechResponse,
        CreateSpeechResponseBody,
        CreateSpeechResponseBodyTypedDict,
        CreateSpeechResponseResult,
        CreateSpeechResponseResultTypedDict,
        CreateSpeechResponseTypedDict,
        Phonemes,
        PhonemesTypedDict,
    )
    from .createclonedvoiceuploadresponse import (
        CreateClonedVoiceUploadResponse,
        CreateClonedVoiceUploadResponseTypedDict,
    )
    from .delete_custom_voiceop import (
        DeleteCustomVoiceRequest,
        DeleteCustomVoiceRequestTypedDict,
    )
    from .edit_custom_voiceop import (
        EditCustomVoiceRequest,
        EditCustomVoiceRequestTypedDict,
    )
    from .forbiddenerrorresponse import (
        ForbiddenErrorResponseMessage,
        ForbiddenErrorResponseMessageTypedDict,
    )
    from .get_custom_voiceop import (
        GetCustomVoiceRequest,
        GetCustomVoiceRequestTypedDict,
    )
    from .get_usageop import (
        BreakdownType,
        BucketWidth,
        GetUsageRequest,
        GetUsageRequestTypedDict,
    )
    from .get_voice_usageop import GetVoiceUsageRequest, GetVoiceUsageRequestTypedDict
    from .get_voiceop import GetVoiceRequest, GetVoiceRequestTypedDict
    from .getapicharacterlistresponse import (
        GetAPICharacterListResponse,
        GetAPICharacterListResponseTypedDict,
    )
    from .getapicharacterresponsedata import (
        GetAPICharacterResponseData,
        GetAPICharacterResponseDataTypedDict,
    )
    from .getcharacterbyidresponse import (
        GetCharacterByIDResponse,
        GetCharacterByIDResponseTypedDict,
    )
    from .getcreditbalanceresponse import (
        GetCreditBalanceResponse,
        GetCreditBalanceResponseTypedDict,
    )
    from .getcustomvoicelistresponse import (
        GetCustomVoiceListResponse,
        GetCustomVoiceListResponseTypedDict,
    )
    from .getcustomvoiceresponsedata import (
        GetCustomVoiceResponseData,
        GetCustomVoiceResponseDataTypedDict,
    )
    from .getsingleclonedvoiceresponse import (
        GetSingleClonedVoiceResponse,
        GetSingleClonedVoiceResponseTypedDict,
    )
    from .getusagelistv1response import (
        GetUsageListV1Response,
        GetUsageListV1ResponseTypedDict,
    )
    from .getusageresponsev1data import (
        GetUsageResponseV1Data,
        GetUsageResponseV1DataTypedDict,
    )
    from .internalservererrorresponse import (
        InternalServerErrorResponseMessage,
        InternalServerErrorResponseMessageTypedDict,
    )
    from .list_custom_voicesop import (
        ListCustomVoicesRequest,
        ListCustomVoicesRequestTypedDict,
    )
    from .list_voicesop import ListVoicesRequest, ListVoicesRequestTypedDict
    from .notfounderrorresponse import (
        NotFoundErrorResponseMessage,
        NotFoundErrorResponseMessageTypedDict,
    )
    from .payloadtoolargeerrorresponse import (
        PayloadTooLargeErrorResponseMessage,
        PayloadTooLargeErrorResponseMessageTypedDict,
    )
    from .paymentrequirederrorresponse import (
        PaymentRequiredErrorResponseMessage,
        PaymentRequiredErrorResponseMessageTypedDict,
    )
    from .predict_durationop import (
        PredictDurationRequest,
        PredictDurationRequestTypedDict,
        PredictDurationResponse,
        PredictDurationResponseTypedDict,
    )
    from .predictttsdurationusingcharacterrequest import (
        PredictTTSDurationUsingCharacterRequest,
        PredictTTSDurationUsingCharacterRequestLanguage,
        PredictTTSDurationUsingCharacterRequestOutputFormat,
        PredictTTSDurationUsingCharacterRequestTypedDict,
    )
    from .requesttimeouterrorresponse import (
        RequestTimeoutErrorResponseMessage,
        RequestTimeoutErrorResponseMessageTypedDict,
    )
    from .search_custom_voicesop import (
        SearchCustomVoicesRequest,
        SearchCustomVoicesRequestTypedDict,
    )
    from .search_voicesop import SearchVoicesRequest, SearchVoicesRequestTypedDict
    from .security import Security, SecurityTypedDict
    from .stream_speechop import (
        StreamSpeechRequest,
        StreamSpeechRequestTypedDict,
        StreamSpeechResponse,
        StreamSpeechResponseResult,
        StreamSpeechResponseResultTypedDict,
        StreamSpeechResponseTypedDict,
    )
    from .toomanyrequestserrorresponse import (
        TooManyRequestsErrorResponseMessage,
        TooManyRequestsErrorResponseMessageTypedDict,
    )
    from .unauthorizederrorresponse import (
        UnauthorizedErrorResponseMessage,
        UnauthorizedErrorResponseMessageTypedDict,
    )
    from .updateclonedvoicerequest import (
        UpdateClonedVoiceRequest,
        UpdateClonedVoiceRequestTypedDict,
    )
    from .updateclonedvoiceresponse import (
        UpdateClonedVoiceResponse,
        UpdateClonedVoiceResponseTypedDict,
    )
    from .usageanalyticsresponse import (
        UsageAnalyticsResponse,
        UsageAnalyticsResponseTypedDict,
    )
    from .usagebucket import UsageBucket, UsageBucketTypedDict
    from .usageresult import UsageResult, UsageResultTypedDict

__all__ = [
    "APIConvertTextToSpeechUsingCharacterRequest",
    "APIConvertTextToSpeechUsingCharacterRequestLanguage",
    "APIConvertTextToSpeechUsingCharacterRequestOutputFormat",
    "APIConvertTextToSpeechUsingCharacterRequestTypedDict",
    "APISampleData",
    "APISampleDataTypedDict",
    "BreakdownType",
    "BucketWidth",
    "ConvertTextToSpeechParameters",
    "ConvertTextToSpeechParametersTypedDict",
    "CreateClonedVoiceRequest",
    "CreateClonedVoiceRequestTypedDict",
    "CreateClonedVoiceUploadResponse",
    "CreateClonedVoiceUploadResponseTypedDict",
    "CreateSpeechRequest",
    "CreateSpeechRequestTypedDict",
    "CreateSpeechResponse",
    "CreateSpeechResponseBody",
    "CreateSpeechResponseBodyTypedDict",
    "CreateSpeechResponseResult",
    "CreateSpeechResponseResultTypedDict",
    "CreateSpeechResponseTypedDict",
    "DeleteCustomVoiceRequest",
    "DeleteCustomVoiceRequestTypedDict",
    "EditCustomVoiceRequest",
    "EditCustomVoiceRequestTypedDict",
    "Files",
    "FilesTypedDict",
    "ForbiddenErrorResponseMessage",
    "ForbiddenErrorResponseMessageTypedDict",
    "GetAPICharacterListResponse",
    "GetAPICharacterListResponseTypedDict",
    "GetAPICharacterResponseData",
    "GetAPICharacterResponseDataTypedDict",
    "GetCharacterByIDResponse",
    "GetCharacterByIDResponseTypedDict",
    "GetCreditBalanceResponse",
    "GetCreditBalanceResponseTypedDict",
    "GetCustomVoiceListResponse",
    "GetCustomVoiceListResponseTypedDict",
    "GetCustomVoiceRequest",
    "GetCustomVoiceRequestTypedDict",
    "GetCustomVoiceResponseData",
    "GetCustomVoiceResponseDataTypedDict",
    "GetSingleClonedVoiceResponse",
    "GetSingleClonedVoiceResponseTypedDict",
    "GetUsageListV1Response",
    "GetUsageListV1ResponseTypedDict",
    "GetUsageRequest",
    "GetUsageRequestTypedDict",
    "GetUsageResponseV1Data",
    "GetUsageResponseV1DataTypedDict",
    "GetVoiceRequest",
    "GetVoiceRequestTypedDict",
    "GetVoiceUsageRequest",
    "GetVoiceUsageRequestTypedDict",
    "InternalServerErrorResponseMessage",
    "InternalServerErrorResponseMessageTypedDict",
    "ListCustomVoicesRequest",
    "ListCustomVoicesRequestTypedDict",
    "ListVoicesRequest",
    "ListVoicesRequestTypedDict",
    "NotFoundErrorResponseMessage",
    "NotFoundErrorResponseMessageTypedDict",
    "PayloadTooLargeErrorResponseMessage",
    "PayloadTooLargeErrorResponseMessageTypedDict",
    "PaymentRequiredErrorResponseMessage",
    "PaymentRequiredErrorResponseMessageTypedDict",
    "Phonemes",
    "PhonemesTypedDict",
    "PredictDurationRequest",
    "PredictDurationRequestTypedDict",
    "PredictDurationResponse",
    "PredictDurationResponseTypedDict",
    "PredictTTSDurationUsingCharacterRequest",
    "PredictTTSDurationUsingCharacterRequestLanguage",
    "PredictTTSDurationUsingCharacterRequestOutputFormat",
    "PredictTTSDurationUsingCharacterRequestTypedDict",
    "RequestTimeoutErrorResponseMessage",
    "RequestTimeoutErrorResponseMessageTypedDict",
    "SearchCustomVoicesRequest",
    "SearchCustomVoicesRequestTypedDict",
    "SearchVoicesRequest",
    "SearchVoicesRequestTypedDict",
    "Security",
    "SecurityTypedDict",
    "StreamSpeechRequest",
    "StreamSpeechRequestTypedDict",
    "StreamSpeechResponse",
    "StreamSpeechResponseResult",
    "StreamSpeechResponseResultTypedDict",
    "StreamSpeechResponseTypedDict",
    "TooManyRequestsErrorResponseMessage",
    "TooManyRequestsErrorResponseMessageTypedDict",
    "UnauthorizedErrorResponseMessage",
    "UnauthorizedErrorResponseMessageTypedDict",
    "UpdateClonedVoiceRequest",
    "UpdateClonedVoiceRequestTypedDict",
    "UpdateClonedVoiceResponse",
    "UpdateClonedVoiceResponseTypedDict",
    "UsageAnalyticsResponse",
    "UsageAnalyticsResponseTypedDict",
    "UsageBucket",
    "UsageBucketTypedDict",
    "UsageResult",
    "UsageResultTypedDict",
]

_dynamic_imports: dict[str, str] = {
    "APIConvertTextToSpeechUsingCharacterRequest": ".apiconverttexttospeechusingcharacterrequest",
    "APIConvertTextToSpeechUsingCharacterRequestLanguage": ".apiconverttexttospeechusingcharacterrequest",
    "APIConvertTextToSpeechUsingCharacterRequestOutputFormat": ".apiconverttexttospeechusingcharacterrequest",
    "APIConvertTextToSpeechUsingCharacterRequestTypedDict": ".apiconverttexttospeechusingcharacterrequest",
    "APISampleData": ".apisampledata",
    "APISampleDataTypedDict": ".apisampledata",
    "ConvertTextToSpeechParameters": ".converttexttospeechparameters",
    "ConvertTextToSpeechParametersTypedDict": ".converttexttospeechparameters",
    "CreateClonedVoiceRequest": ".create_cloned_voiceop",
    "CreateClonedVoiceRequestTypedDict": ".create_cloned_voiceop",
    "Files": ".create_cloned_voiceop",
    "FilesTypedDict": ".create_cloned_voiceop",
    "CreateSpeechRequest": ".create_speechop",
    "CreateSpeechRequestTypedDict": ".create_speechop",
    "CreateSpeechResponse": ".create_speechop",
    "CreateSpeechResponseBody": ".create_speechop",
    "CreateSpeechResponseBodyTypedDict": ".create_speechop",
    "CreateSpeechResponseResult": ".create_speechop",
    "CreateSpeechResponseResultTypedDict": ".create_speechop",
    "CreateSpeechResponseTypedDict": ".create_speechop",
    "Phonemes": ".create_speechop",
    "PhonemesTypedDict": ".create_speechop",
    "CreateClonedVoiceUploadResponse": ".createclonedvoiceuploadresponse",
    "CreateClonedVoiceUploadResponseTypedDict": ".createclonedvoiceuploadresponse",
    "DeleteCustomVoiceRequest": ".delete_custom_voiceop",
    "DeleteCustomVoiceRequestTypedDict": ".delete_custom_voiceop",
    "EditCustomVoiceRequest": ".edit_custom_voiceop",
    "EditCustomVoiceRequestTypedDict": ".edit_custom_voiceop",
    "ForbiddenErrorResponseMessage": ".forbiddenerrorresponse",
    "ForbiddenErrorResponseMessageTypedDict": ".forbiddenerrorresponse",
    "GetCustomVoiceRequest": ".get_custom_voiceop",
    "GetCustomVoiceRequestTypedDict": ".get_custom_voiceop",
    "BreakdownType": ".get_usageop",
    "BucketWidth": ".get_usageop",
    "GetUsageRequest": ".get_usageop",
    "GetUsageRequestTypedDict": ".get_usageop",
    "GetVoiceUsageRequest": ".get_voice_usageop",
    "GetVoiceUsageRequestTypedDict": ".get_voice_usageop",
    "GetVoiceRequest": ".get_voiceop",
    "GetVoiceRequestTypedDict": ".get_voiceop",
    "GetAPICharacterListResponse": ".getapicharacterlistresponse",
    "GetAPICharacterListResponseTypedDict": ".getapicharacterlistresponse",
    "GetAPICharacterResponseData": ".getapicharacterresponsedata",
    "GetAPICharacterResponseDataTypedDict": ".getapicharacterresponsedata",
    "GetCharacterByIDResponse": ".getcharacterbyidresponse",
    "GetCharacterByIDResponseTypedDict": ".getcharacterbyidresponse",
    "GetCreditBalanceResponse": ".getcreditbalanceresponse",
    "GetCreditBalanceResponseTypedDict": ".getcreditbalanceresponse",
    "GetCustomVoiceListResponse": ".getcustomvoicelistresponse",
    "GetCustomVoiceListResponseTypedDict": ".getcustomvoicelistresponse",
    "GetCustomVoiceResponseData": ".getcustomvoiceresponsedata",
    "GetCustomVoiceResponseDataTypedDict": ".getcustomvoiceresponsedata",
    "GetSingleClonedVoiceResponse": ".getsingleclonedvoiceresponse",
    "GetSingleClonedVoiceResponseTypedDict": ".getsingleclonedvoiceresponse",
    "GetUsageListV1Response": ".getusagelistv1response",
    "GetUsageListV1ResponseTypedDict": ".getusagelistv1response",
    "GetUsageResponseV1Data": ".getusageresponsev1data",
    "GetUsageResponseV1DataTypedDict": ".getusageresponsev1data",
    "InternalServerErrorResponseMessage": ".internalservererrorresponse",
    "InternalServerErrorResponseMessageTypedDict": ".internalservererrorresponse",
    "ListCustomVoicesRequest": ".list_custom_voicesop",
    "ListCustomVoicesRequestTypedDict": ".list_custom_voicesop",
    "ListVoicesRequest": ".list_voicesop",
    "ListVoicesRequestTypedDict": ".list_voicesop",
    "NotFoundErrorResponseMessage": ".notfounderrorresponse",
    "NotFoundErrorResponseMessageTypedDict": ".notfounderrorresponse",
    "PayloadTooLargeErrorResponseMessage": ".payloadtoolargeerrorresponse",
    "PayloadTooLargeErrorResponseMessageTypedDict": ".payloadtoolargeerrorresponse",
    "PaymentRequiredErrorResponseMessage": ".paymentrequirederrorresponse",
    "PaymentRequiredErrorResponseMessageTypedDict": ".paymentrequirederrorresponse",
    "PredictDurationRequest": ".predict_durationop",
    "PredictDurationRequestTypedDict": ".predict_durationop",
    "PredictDurationResponse": ".predict_durationop",
    "PredictDurationResponseTypedDict": ".predict_durationop",
    "PredictTTSDurationUsingCharacterRequest": ".predictttsdurationusingcharacterrequest",
    "PredictTTSDurationUsingCharacterRequestLanguage": ".predictttsdurationusingcharacterrequest",
    "PredictTTSDurationUsingCharacterRequestOutputFormat": ".predictttsdurationusingcharacterrequest",
    "PredictTTSDurationUsingCharacterRequestTypedDict": ".predictttsdurationusingcharacterrequest",
    "RequestTimeoutErrorResponseMessage": ".requesttimeouterrorresponse",
    "RequestTimeoutErrorResponseMessageTypedDict": ".requesttimeouterrorresponse",
    "SearchCustomVoicesRequest": ".search_custom_voicesop",
    "SearchCustomVoicesRequestTypedDict": ".search_custom_voicesop",
    "SearchVoicesRequest": ".search_voicesop",
    "SearchVoicesRequestTypedDict": ".search_voicesop",
    "Security": ".security",
    "SecurityTypedDict": ".security",
    "StreamSpeechRequest": ".stream_speechop",
    "StreamSpeechRequestTypedDict": ".stream_speechop",
    "StreamSpeechResponse": ".stream_speechop",
    "StreamSpeechResponseResult": ".stream_speechop",
    "StreamSpeechResponseResultTypedDict": ".stream_speechop",
    "StreamSpeechResponseTypedDict": ".stream_speechop",
    "TooManyRequestsErrorResponseMessage": ".toomanyrequestserrorresponse",
    "TooManyRequestsErrorResponseMessageTypedDict": ".toomanyrequestserrorresponse",
    "UnauthorizedErrorResponseMessage": ".unauthorizederrorresponse",
    "UnauthorizedErrorResponseMessageTypedDict": ".unauthorizederrorresponse",
    "UpdateClonedVoiceRequest": ".updateclonedvoicerequest",
    "UpdateClonedVoiceRequestTypedDict": ".updateclonedvoicerequest",
    "UpdateClonedVoiceResponse": ".updateclonedvoiceresponse",
    "UpdateClonedVoiceResponseTypedDict": ".updateclonedvoiceresponse",
    "UsageAnalyticsResponse": ".usageanalyticsresponse",
    "UsageAnalyticsResponseTypedDict": ".usageanalyticsresponse",
    "UsageBucket": ".usagebucket",
    "UsageBucketTypedDict": ".usagebucket",
    "UsageResult": ".usageresult",
    "UsageResultTypedDict": ".usageresult",
}


def __getattr__(attr_name: str) -> object:
    module_name = _dynamic_imports.get(attr_name)
    if module_name is None:
        raise AttributeError(
            f"No {attr_name} found in _dynamic_imports for module name -> {__name__} "
        )

    try:
        module = import_module(module_name, __package__)
        result = getattr(module, attr_name)
        return result
    except ImportError as e:
        raise ImportError(
            f"Failed to import {attr_name} from {module_name}: {e}"
        ) from e
    except AttributeError as e:
        raise AttributeError(
            f"Failed to get {attr_name} from {module_name}: {e}"
        ) from e


def __dir__():
    lazy_attrs = builtins.list(_dynamic_imports.keys())
    return builtins.sorted(lazy_attrs)
