"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UsageResultTypedDict(TypedDict):
    minutes_used: float
    r"""Total minutes of API usage"""
    voice_id: NotRequired[str]
    r"""Voice identifier"""
    voice_name: NotRequired[str]
    r"""Human-readable voice name"""
    api_key: NotRequired[str]
    r"""API key used"""
    model: NotRequired[str]
    r"""Model used"""


class UsageResult(BaseModel):
    minutes_used: float
    r"""Total minutes of API usage"""

    voice_id: Optional[str] = None
    r"""Voice identifier"""

    voice_name: Optional[str] = None
    r"""Human-readable voice name"""

    api_key: Optional[str] = None
    r"""API key used"""

    model: Optional[str] = None
    r"""Model used"""
