"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class UpdateClonedVoiceRequestTypedDict(TypedDict):
    name: NotRequired[str]
    r"""Name of the voice"""
    description: NotRequired[str]
    r"""Description of the voice"""


class UpdateClonedVoiceRequest(BaseModel):
    name: Optional[str] = None
    r"""Name of the voice"""

    description: Optional[str] = None
    r"""Description of the voice"""
