"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing import Optional
from typing_extensions import NotRequired, TypedDict


class ConvertTextToSpeechParametersTypedDict(TypedDict):
    pitch_shift: NotRequired[float]
    pitch_variance: NotRequired[float]
    speed: NotRequired[float]
    duration: NotRequired[float]
    r"""Duration parameter for TTS generation"""
    similarity: NotRequired[float]
    r"""Similarity parameter for voice matching"""
    text_guidance: NotRequired[float]
    r"""Text guidance parameter for generation control"""
    subharmonic_amplitude_control: NotRequired[float]
    r"""Subharmonic amplitude control parameter"""


class ConvertTextToSpeechParameters(BaseModel):
    pitch_shift: Optional[float] = 0

    pitch_variance: Optional[float] = 1

    speed: Optional[float] = 1

    duration: Optional[float] = 0
    r"""Duration parameter for TTS generation"""

    similarity: Optional[float] = 3
    r"""Similarity parameter for voice matching"""

    text_guidance: Optional[float] = 1
    r"""Text guidance parameter for generation control"""

    subharmonic_amplitude_control: Optional[float] = 1
    r"""Subharmonic amplitude control parameter"""
