"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from supertone.types import BaseModel
from typing_extensions import TypedDict


class GetSingleClonedVoiceResponseTypedDict(TypedDict):
    voice_id: str
    r"""Unique identifier for the voice"""
    name: str
    r"""Name of the voice"""
    description: str
    r"""Description of the voice"""


class GetSingleClonedVoiceResponse(BaseModel):
    voice_id: str
    r"""Unique identifier for the voice"""

    name: str
    r"""Name of the voice"""

    description: str
    r"""Description of the voice"""
